<?php 
// tig.maths.Vector3.php
// Software released under the General Public License (version 2 or later), available at
// http://www.gnu.org/copyleft/gpl.html

require_once(dirname(__FILE__) . "/uMaths.php");

/****************************************************************************************
A vector in a 3D space.

@license  GPL
@author   <a href="http://www.tig12.net">Thierry Graff</a>
@history 2002.10.10 : Creation (or 2002.10.30 ???)
@history 2008.05.28 PH5 version
****************************************************************************************/
class Vector3{
  /** first coordinate */
  public $x0;
  /** second coordinate */
  public $x1;
  /** third coordinate */
  public $x2;

  // *************************** __construct ***************************
  /** Constructor from 3 scalars */
  public function __construct($x0, $x1, $x2){
    $this->x0 = $x0; $this->x1 = $x1; $this->x2 = $x2;
  }// end __construct

  // ***************************  ***************************
  /** Returns a coordinate, using uMaths class constants. */
  public function getCoord($whichCoord){
    switch($whichCoord){
      case COORD_X0 : return $this->x0; break;
      case COORD_X1 : return $this->x1; break;
      case COORD_X2 : return $this->x2; break;
    }
  }// end getCoords
  
  
  // *************************** toArray ***************************
  /**
    Returns an associative array containing 3 entries, with keys : 'x0', 'x1', 'x2'
  */
  public function toArray(){
    return array('x0' => $this->x0, 'x1' =>$this->x1 , 'x2' =>$this->x2 );
  }// end toArray()
  
  
  // *************************** norm ***************************
  /** Returns the norm of this vector. */
  function norm(){
    return sqrt($this->x0*$this->x0 + $this->x1*$this->x1 + $this->x2*$this->x2);
  }// end norm

  //========================================================
  //                                              Static methods
  //========================================================
  
  // *************************** sub ***************************
  /**
    Substraction of vectors. 
    @return $v1 - $v2.
  */
  function sub($v1, $v2){
    return new Vector3($v1->x0 - $v2->x0, $v1->x1 - $v2->x1, $v1->x2 - $v2->x2);
  }// end sub
  
  
} // end class


 ?>