<?php
// Software released under the General Public License (version 2 or later), available at
// http://www.gnu.org/copyleft/gpl.html
/*********************************************************************************
Interface containing constants to identify units.

@author <a href="http://www.tig12.net">Thierry Graff</a>
@history 2002.02.16 : Creation from Units
@history 2007.12.14 : PH5 port from java
**********************************************************************************/
interface UnitConstants{

  // ***** Degree formatting ********
  /** Constant used to indicate that degrees should be formated as "degrees minutes seconds"
  (ex : <CODE>123°18'23"</CODE>). */
  const DEGREES_DMS = 'DMS';
  /** Constant used to indicate that degrees should be formated as decimal degrees. */
  const DEGREES_DECIMAL = 'deg';

  //******************************************************
  // Constants to desingate unit types.
  //******************************************************
  // ***** Distance units ********
  /** Constant designating units of type "linear disance". */
  const TYPE_DISTANCE = 'distance';
  /** Constant designating units of type "linear speed". */
  const TYPE_LINEAR_SPEED = 'linear_speed';
  /** Constant designating units of type "angular". */
  const TYPE_ANGULAR = 'angular';
  /** Constant designating units of type "angular speed". */
  const TYPE_ANGULAR_SPEED = 'angular_speed';

  //******************************************************
  // Constants to desingate units.
  //******************************************************

  // ***** Distance units (metric units) ********
  /** Constant designating the "astronomical unit" unit. */
  const DISTANCE_UNIT_AU = 'au';
  /** Constant designating the "kilometer" unit. */
  const DISTANCE_UNIT_KM = 'km';
  /** Constant designating the "meter"  unit. */
  const DISTANCE_UNIT_M = 'm';

  // ***** Linear speed units ********
  /** Constant designating the "astronomical unit per day" unit. */
  const LINEAR_SPEED_UNIT_AU_PER_D = 'au/d';
  /** Constant designating the "kilometer per day" unit. */
  const LINEAR_SPEED_UNIT_KM_PER_D = 'km/d';
  /** Constant designating the "kilometer per hour" unit. */
  const LINEAR_SPEED_UNIT_KM_PER_HOUR = 'km/h';
  /** Constant designating the "meter per second" unit. */
  const LINEAR_SPEED_UNIT_M_PER_S = 'm/s';

  // ***** Angular units ********
  /** Constant designating the "arc second" unit. */
  const ANGULAR_UNIT_ARCSEC = 'arcsec';
  /** Constant designating the "decimal degree" unit. */
  const ANGULAR_UNIT_DEG = 'deg';
  /** Constant designating the "radian" unit. */
  const ANGULAR_UNIT_RAD = 'rad';

  // ***** Angular speed units ********
  /** Constant designating the "arc second per time second" unit. */
  const ANGULAR_SPEED_UNIT_ARCSEC_PER_S = 'arcsec/s';
  /** Constant designating the "degree per second" unit. */
  const ANGULAR_SPEED_UNIT_DEG_PER_S = 'deg/s';
  /** Constant designating the "arc second per day" unit. */
  const ANGULAR_SPEED_UNIT_ARCSEC_PER_DAY = 'arcsec/d';
  /** Constant designating the "degree per day" unit. */
  const ANGULAR_SPEED_UNIT_DEG_PER_DAY = 'deg/d';
  /** Constant designating the "radian per day" unit. */
  const ANGULAR_SPEED_UNIT_RAD_PER_DAY = 'rad/d';

  //******************************************************
  // Constants to desingate groups of 3 units.
  //******************************************************
  /** Constant designating the "a.u., a.u., a.u." group of units (for positions, cartesian coordinates). */
  const UNITGROUP_AU_AU_AU = array( DISTANCE_UNIT_AU,
                                                   DISTANCE_UNIT_AU,
                                                   DISTANCE_UNIT_AU
                                                 );
  /** Constant designating the "a.u., a.u., a.u." group of units (for positions, cartesian coordinates). */
  const UNITGROUP_KM_KM_KM = array( DISTANCE_UNIT_KM,
                                                   DISTANCE_UNIT_KM,
                                                   DISTANCE_UNIT_KM
                                                 );
  /** Constant designating the "au/d, au/d, au/d" group of units (for velocities, cartesian coordinates). */
  const UNITGROUP_AUD_AUD_AUD = array( LINEAR_SPEED_UNIT_AU_PER_D,
                                                      LINEAR_SPEED_UNIT_AU_PER_D,
                                                      LINEAR_SPEED_UNIT_AU_PER_D
                                                    );
  /** Constant designating the "a.u., rad, rad" group of units (for positions, spherical coordinates). */
  const UNITGROUP_AU_RAD_RAD = array( DISTANCE_UNIT_AU,
                                                     ANGULAR_UNIT_RAD,
                                                     ANGULAR_UNIT_RAD
                                                   );

  /** Constant designating the "a.u., deg, deg" group of units (for positions, spherical coordinates). */
  const UNITGROUP_AU_DEG_DEG = array( DISTANCE_UNIT_AU,
                                                     ANGULAR_UNIT_DEG,
                                                     ANGULAR_UNIT_DEG
                                                   );

}//end interface UnitConstants
?>